@@ -30,11 +30,11 @@ Log::AutoDump - Log with automatic dumping of references and objects.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 $VERSION = eval $VERSION;
 
@@ -491,9 +491,9 @@ sub debug
 
     if ( scalar( @_ ) == 1 && $_[ 0 ] =~ /^#/ && $_[ 0 ] =~ /#$/ )
     {
-        $self->msg( DEBUG, '#' x strlen( $_[ 0 ] ) ) if $self->is_debug;
+        $self->msg( DEBUG, '#' x length( $_[ 0 ] ) ) if $self->is_debug;
         $self->msg( DEBUG, @_ ) if $self->is_debug;
-        $self->msg( DEBUG, '#' x strlen( $_[ 0 ] ) ) if $self->is_debug;
+        $self->msg( DEBUG, '#' x length( $_[ 0 ] ) ) if $self->is_debug;
     }
     else
     {
